@@ -424,9 +424,8 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * @end: the end of the updated region
 	 *
 	 * The ::highlight-updated signal is emitted when the syntax
-	 * highlighting is updated in a certain region of the @buffer. This
-	 * signal is useful to be notified when a context class region is
-	 * updated (e.g. the no-spell-check context class).
+	 * highlighting and [context classes][context-classes] are updated in a
+	 * certain region of the @buffer.
 	 */
 	buffer_signals[HIGHLIGHT_UPDATED] =
 	    g_signal_new_class_handler ("highlight-updated",
@@ -2054,6 +2053,12 @@ gtk_source_buffer_create_source_mark (GtkSourceBuffer   *buffer,
 				  GTK_TEXT_MARK (mark),
 				  where);
 
+	/* We want to return a borrowed reference and the mark is already
+	 * owned by @buffer due to gtk_text_buffer_add_mark(). Therefore
+	 * it is safe to unref immediately.
+	 */
+	g_object_unref (mark);
+
 	return mark;
 }
 
@@ -2939,10 +2944,16 @@ gtk_source_buffer_sort_lines (GtkSourceBuffer    *buffer,
 	start_line = gtk_text_iter_get_line (start);
 	end_line = gtk_text_iter_get_line (end);
 
+	/* Required for gtk_text_buffer_delete() */
+	if (!gtk_text_iter_starts_line (start))
+	{
+		gtk_text_iter_set_line_offset (start, 0);
+	}
+
 	/* if we are at line start our last line is the previus one.
 	 * Otherwise the last line is the current one but we try to
 	 * move the iter after the line terminator */
-	if (gtk_text_iter_get_line_offset (end) == 0)
+	if (gtk_text_iter_starts_line (end))
 	{
 		end_line = MAX (start_line, end_line - 1);
 	}
@@ -2951,6 +2962,11 @@ gtk_source_buffer_sort_lines (GtkSourceBuffer    *buffer,
 		gtk_text_iter_forward_line (end);
 	}
 
+	if (start_line == end_line)
+	{
+		return;
+	}
+
 	num_lines = end_line - start_line + 1;
 	lines = g_new0 (SortLine, num_lines);
 
