@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_COMPLETION_MODEL_H__
-#define __GTK_SOURCE_COMPLETION_MODEL_H__
+#ifndef GTK_SOURCE_COMPLETION_MODEL_H
+#define GTK_SOURCE_COMPLETION_MODEL_H
 
 #include <gtk/gtk.h>
 #include "gtksourcetypes.h"
@@ -127,4 +127,4 @@ gboolean gtk_source_completion_model_iter_equal			(GtkSourceCompletionModel    *
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_COMPLETION_MODEL_H__ */
+#endif /* GTK_SOURCE_COMPLETION_MODEL_H */
