@@ -1041,16 +1041,6 @@ parse_style (GtkSourceStyleScheme *scheme,
 	tmp = xmlGetProp (node, BAD_CAST "use-style");
 	if (tmp != NULL)
 	{
-		if (use_style != NULL)
-		{
-			g_set_error (error, ERROR_QUARK, 0,
-				     "in style '%s': duplicated use-style attribute",
-				     style_name);
-			g_free (style_name);
-			g_object_unref (use_style);
-			return FALSE;
-		}
-
 		use_style = gtk_source_style_scheme_get_style (scheme, (char*) tmp);
 
 		if (use_style == NULL)
@@ -1452,6 +1442,11 @@ _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme));
 	g_return_if_fail (parent_scheme == NULL || GTK_SOURCE_IS_STYLE_SCHEME (parent_scheme));
 
+	if (scheme->priv->parent == parent_scheme)
+	{
+		return;
+	}
+
 	g_clear_object (&scheme->priv->parent);
 
 	if (parent_scheme != NULL)
@@ -1460,6 +1455,10 @@ _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
 	}
 
 	scheme->priv->parent = parent_scheme;
+
+	/* Update CSS based on parent styles */
+	g_hash_table_remove_all (scheme->priv->style_cache);
+	generate_css_style (scheme);
 }
 
 /**
